#!/bin/bash

PROG=$(basename $0)
CWD=$(cd $(dirname $0) && pwd)

PORTAL_INIT_SCRIPT="framework/etc/agsportal.sh"
SERVER_INIT_SCRIPT="framework/etc/scripts/agsserver.sh"
DATASTORE_INIT_SCRIPT="framework/etc/scripts/arcgisdatastore.sh"

usage()
{
  cat <<EOF

  ${PROG} - Run a post-applypatch operation

  USAGE: % ./${PROG} [product_install_dir]

EOF
  exit 0
}

fail()
{
  echo ""
  echo "ERROR: $1"
  echo ""
  exit 1
}

run_step()
{
  INSTALL_SCRIPT="${1}/${PORTAL_INIT_SCRIPT}"

  if [ ! -f "$INSTALL_SCRIPT" ]; then
    echo "Could not find install script: $INSTALL_SCRIPT. Skipping post-install step."
    return
  fi

  CMD="${INSTALL_SCRIPT} updateFiles log4j"
  echo "Running command: $CMD"

  # Run it
  eval $CMD
  [ $? -ne 0 ] && fail "Post-install step failed"

  echo ""
  echo "Post-install step SUCCEEDED!"
}

Main()
{
  [ $# -ne 1 ] && usage

  run_step "$1"
}

Main "$@"

